# useful_types

This package contains useful types!

Are you tired of defining the same protocols and type aliases over and over in your projects?
Look no further.

The types in this package are not special cased by type checkers in any way. Feel free to vendor
them in your project instead of depending on this package.

While most of this library will work on any recent type checker version,
some types depend on newer type checker features. We guarantee
support on mypy 1.4 and pyright 1.1.314 or higher.
